
'use strict';
{
  const globals = this;
  const django = globals.django || (globals.django = {});

  
  django.pluralidx = function(n) {
    const v = (n != 1);
    if (typeof v === 'boolean') {
      return v ? 1 : 0;
    } else {
      return v;
    }
  };
  

  /* gettext library */

  django.catalog = django.catalog || {};
  
  const newcatalog = {
    "(If left blank, owner will be admin)": "(jos j\u00e4tetty tyhj\u00e4ksi, omistaja on admin)",
    "(at least {passwordMinLength} characters and includes {passwordStrengthLevel} of the following: number, upper letter, lower letter and other symbols)": "(at least {passwordMinLength} characters and includes {passwordStrengthLevel} of the following: number, upper letter, lower letter and other symbols)",
    "(at least {placeholder} characters)": "(at least {placeholder} characters)",
    "(current notification)": "(nykyinen ilmoitus)",
    "(current version)": "(nykyinen versio",
    "1 Year": "1 Vuosi",
    "1 cell copied": "1 cell copied",
    "1 filter": "1 filter",
    "1 hidden property": "1 hidden property",
    "1 month ago": "1 kuukausi sitten",
    "1 preset hidden property": "1 preset hidden property",
    "1 record selected": "1 record selected",
    "1 row is copied.": "1 row is copied.",
    "1 sort": "1 sort",
    "1 week ago": "1 viikko sitten",
    "3 days ago": "3 p\u00e4iv\u00e4\u00e4 sitten",
    "30 Days": "30 P\u00e4iv\u00e4\u00e4",
    "7 Days": "7 P\u00e4iv\u00e4\u00e4",
    "A file is being uploaded. Are you sure you want to leave this page?": "A file is being uploaded. Are you sure you want to leave this page?",
    "A file named {upload_file_link} is uploaded to {uploaded_link}.": "A file named {upload_file_link} is uploaded to {uploaded_link}.",
    "A file named {upload_file_link} is uploaded.": "A file named {upload_file_link} is uploaded.",
    "A file with the same name already exists in this folder.": "Hakemistossa on jo saman niminen tiedosto.",
    "A folder named {upload_folder_link} is uploaded to {uploaded_link}.": "A folder named {upload_folder_link} is uploaded to {uploaded_link}.",
    "A folder named {upload_folder_link} is uploaded.": "A folder named {upload_folder_link} is uploaded.",
    "API Token": "API Token",
    "API token is copied to the clipboard.": "API token is copied to the clipboard.",
    "About": "Tietoa",
    "About Us": "Tietoa meist\u00e4",
    "Abuse Content": "Abuse Content",
    "Abuse Reports": "Abuse Reports",
    "Abuse Type": "Abuse Type",
    "Abuse report added": "Abuse report added",
    "Accept": "Hyv\u00e4ksy",
    "Accepted": "Hyv\u00e4ksytty",
    "Accepted at": "Hyv\u00e4ksytty kohteessa",
    "Accepter": "Hyv\u00e4ksyj\u00e4",
    "Access Log": "K\u00e4ytt\u00f6logi",
    "Accurate to minute": "Accurate to minute",
    "Action": "Toiminto",
    "Actions": "Toiminnot",
    "Activate user immediately after registration. If unchecked, a user need to be activated by administrator or via activation email": "Aktivoi k\u00e4ytt\u00e4j\u00e4 heti rekister\u00f6innin j\u00e4lkeen. Jos ei valittuna, j\u00e4rjestelm\u00e4nvalvojan pit\u00e4\u00e4 aktivoida k\u00e4ytt\u00e4j\u00e4 tai aktivointi s\u00e4hk\u00f6postilla.",
    "Activated": "Aktivoitu",
    "Activated Users": "Aktivoidut k\u00e4ytt\u00e4j\u00e4t",
    "Active": "Aktiivinen",
    "Active Users": "Aktiiviset k\u00e4ytt\u00e4j\u00e4t",
    "Activities": "Aktiviteetit",
    "Add": "Lis\u00e4\u00e4",
    "Add Admin": "Add Admin",
    "Add Library": "Lis\u00e4\u00e4 kirjasto",
    "Add Member": "Lis\u00e4\u00e4 J\u00e4seni\u00e4",
    "Add Organization": "Add Organization",
    "Add Terms and Conditions": "Lis\u00e4\u00e4 K\u00e4ytt\u00f6ehdot",
    "Add User": "Lis\u00e4\u00e4 K\u00e4ytt\u00e4j\u00e4",
    "Add Wiki": "Lis\u00e4\u00e4 Wiki",
    "Add admin": "Lis\u00e4\u00e4 yll\u00e4pit\u00e4j\u00e4",
    "Add auto expiration": "Lis\u00e4\u00e4 automaattinen vanheneminen",
    "Add cover": "Add cover",
    "Add custom permission": "Add custom permission",
    "Add group": "Add group",
    "Add group member": "Add group member",
    "Add icon": "Add icon",
    "Add institution": "Lis\u00e4\u00e4 instituutio",
    "Add members": "Lis\u00e4\u00e4 k\u00e4ytt\u00e4j\u00e4t",
    "Add new notification": "Lis\u00e4\u00e4 uusi ilmoitus",
    "Add option": "Add option",
    "Add password protection": "Lis\u00e4\u00e4 salasanasuojaus",
    "Add permission": "Add permission",
    "Add user": "Lis\u00e4\u00e4 k\u00e4ytt\u00e4j\u00e4",
    "Add view": "Add view",
    "Added": "Lis\u00e4tty",
    "Added user {user}": "Lis\u00e4tty k\u00e4ytt\u00e4j\u00e4 {user}",
    "Admin": "Yll\u00e4pit\u00e4j\u00e4",
    "Admin Login Logs": "Admin Kirjautumis Lokit",
    "Admin Logs": "Admin Logit",
    "Admin Operation Logs": "Admin Operaatio Lokit",
    "Admin access": "Admin access",
    "Admins": "Yll\u00e4pit\u00e4j\u00e4t",
    "Advanced": "Advanced",
    "After enable extended properties for files, you can add different properties to files, like collaborators, file expiring time, file description. You can also create different views for files based extended properties.": "After enable extended properties for files, you can add different properties to files, like collaborators, file expiring time, file description. You can also create different views for files based extended properties.",
    "All": "Kaikki",
    "All Groups": "Kaikki ryhm\u00e4t",
    "All Notifications": "Kaikki ilmoitukset",
    "All Public Links": "Kaikki julkiset linkit",
    "Allow new user registrations. Uncheck this to prevent anyone from creating a new account.": "Salli uusien k\u00e4ytt\u00e4jien rekister\u00f6itymisen. Poistamalla t\u00e4m\u00e4n valinnan est\u00e4\u00e4 uusien tilien luonnin.",
    "An integer that is greater than 0 or equal to -2.": "Integer joka on suurempi kuin 0 tai samansuuruinen kuin -2.",
    "An integer that is greater than or equal to 0.": "Integer joka on suurempi tai samansuuruinen kuin 0.",
    "An internal link is a link to a file or folder that can be accessed by users with read permission to the file or folder.": "An internal link is a link to a file or folder that can be accessed by users with read permission to the file or folder.",
    "And": "And",
    "Anonymous User": "Anonyymi k\u00e4ytt\u00e4j\u00e4",
    "Another property has this property type": "Another property has this property type",
    "Another user is editing this file!": "Another user is editing this file!",
    "Anyone with the link": "Anyone with the link",
    "Are you sure to change group {placeholder} to department ?": "Are you sure to change group {placeholder} to department ?",
    "Are you sure to delete": "Haluatko varmasti poistaa",
    "Are you sure to delete ": "Are you sure to delete ",
    "Are you sure to revoke access of user {placeholder} ?": "Are you sure to revoke access of user {placeholder} ?",
    "Are you sure you want to clear trash?": "Oletko varma, ett\u00e4 haluat tyhjent\u00e4\u00e4 roskakorin?",
    "Are you sure you want to delete": "Are you sure you want to delete",
    "Are you sure you want to delete WebDAV password?": "Are you sure you want to delete WebDAV password?",
    "Are you sure you want to delete the notification ?": "Are you sure you want to delete the notification ?",
    "Are you sure you want to delete the selected share link(s) ?": "Are you sure you want to delete the selected share link(s) ?",
    "Are you sure you want to delete the selected user(s) ?": "Oletko varma, ett\u00e4 haluat poistaa valitun k\u00e4ytt\u00e4j\u00e4n (k\u00e4ytt\u00e4j\u00e4t)?",
    "Are you sure you want to delete this page?": "Oletko varma, ett\u00e4 haluat poistaa t\u00e4m\u00e4n sivun?",
    "Are you sure you want to delete {placeholder} ?": "Are you sure you want to delete {placeholder} ?",
    "Are you sure you want to delete {placeholder} completely?": "Are you sure you want to delete {placeholder} completely?",
    "Are you sure you want to disconnect?": "Are you sure you want to disconnect?",
    "Are you sure you want to remove {placeholder} ?": "Are you sure you want to remove {placeholder} ?",
    "Are you sure you want to reset the password of {placeholder} ?": "Are you sure you want to reset the password of {placeholder} ?",
    "Are you sure you want to restore this library?": "Oletko varma, ett\u00e4 haluat palauttaa t\u00e4m\u00e4n kirjaston?",
    "Are you sure you want to restore {placeholder}?": "Are you sure you want to restore {placeholder}?",
    "Are you sure you want to revoke the admin permission of {placeholder} ?": "Are you sure you want to revoke the admin permission of {placeholder} ?",
    "Are you sure you want to set {placeholder} as Admin?": "Are you sure you want to set {placeholder} as Admin?",
    "Are you sure you want to set {user_placeholder} inactive?": "Are you sure you want to set {user_placeholder} inactive?",
    "Are you sure you want to unlink this device?": "Oletko varma, ett\u00e4 haluat poistaa yhdistetyn laitteen?",
    "At server": "At server",
    "Audio": "Audio",
    "Auth Token created": "Auth Token created",
    "Auth Token deleted": "Auth Token deleted",
    "Auto deletion": "Auto deletion",
    "Automatically delete files that are not modified within certain days:": "Automatically delete files that are not modified within certain days:",
    "Avatar": "Avatar",
    "Avatar updated": "Avatar updated",
    "Avatar:": "Avatar:",
    "Back": "Takaisin",
    "Basic": "Basic",
    "Bell Icon": "Bell Icon",
    "Besides Write permission, user can also share the library.": "Besides Write permission, user can also share the library.",
    "Branding": "Br\u00e4nd\u00e4ys",
    "Broken (please contact your administrator to fix this library)": "Virheellinen (ole hyv\u00e4 ja ota yhteytt\u00e4 j\u00e4rjestelm\u00e4n yll\u00e4pit\u00e4j\u00e4\u00e4n korjataksesi t\u00e4m\u00e4n kirjaston)",
    "By day": "By day",
    "By month": "By month",
    "By name ascending": "By name ascending",
    "By name descending": "By name descending",
    "By quarter": "By quarter",
    "By size ascending": "By size ascending",
    "By size descending": "By size descending",
    "By time ascending": "By time ascending",
    "By time descending": "By time descending",
    "By week": "By week",
    "By year": "By year",
    "Can not copy folder %(src)s to its subfolder %(des)s": "Can not copy folder %(src)s to its subfolder %(des)s",
    "Can not move folder %(src)s to its subfolder %(des)s": "Can not move folder %(src)s to its subfolder %(des)s",
    "Cancel": "Peruuta",
    "Cancel All": "Peruuta kaikki",
    "Cannot move parent page to child page": "Cannot move parent page to child page",
    "Capture information": "Capture information",
    "Capture time": "Capture time",
    "Certificate": "Certificate",
    "Change": "Muuta",
    "Change Password": "Vaihda salasana",
    "Change Password of Library {placeholder}": "Vaihda kirjaston {placeholder} salasana",
    "Change cover": "Change cover",
    "Change group to department": "Change group to department",
    "Change to department": "Change to department",
    "Changes": "Changes",
    "Checkbox": "Checkbox",
    "Choose date": "Choose date",
    "Clean": "Siivoa",
    "Clean succeeded.": "Clean succeeded.",
    "Cleaned trash": "Cleaned trash",
    "Clear": "Tyhjenn\u00e4",
    "Clear Trash": "Tyhjenn\u00e4 Roskakori",
    "Clear files in trash and history\uff1a": "Poista historia ja tiedostot roskakorista :",
    "Clear selected": "Clear selected",
    "Clients": "Asiakasohjelmat",
    "Close": "Sulje",
    "Close (Esc)": "Sulje (Esc)",
    "Code": "Code",
    "Collaborator": "Collaborator",
    "Collapse all": "Collapse all",
    "Color space": "Color space",
    "Comment": "Kommentti",
    "Comments": "Kommentit",
    "Community Edition": "Community versio",
    "Compressed": "Compressed",
    "Configure Seafile": "Configure Seafile",
    "Configure your Identity Provider": "Configure your Identity Provider",
    "Confirm": "Confirm",
    "Confirm Password": "Vahvista salasana",
    "Confirm password": "Confirm password",
    "Connect": "Connect",
    "Contact Email": "Yhteyss\u00e4hk\u00f6posti",
    "Contact Email:": "S\u00e4hk\u00f6posti",
    "Contact Information": "Contact Information",
    "Contact information is required.": "Contact information is required.",
    "Content Scan Records": "Content Scan Records",
    "Convert & Export": "Convert & Export",
    "Convert Wiki": "Convert Wiki",
    "Convert to Markdown": "Convert to Markdown",
    "Convert to docx": "Convert to docx",
    "Convert to sdoc": "Convert to sdoc",
    "Convert with ONLYOFFICE": "Convert with ONLYOFFICE",
    "Converting, please wait...": "Converting, please wait...",
    "Copied": "Copied",
    "Copied link to clipboard": "Copied link to clipboard",
    "Copy": "Kopioi",
    "Copy failed": "Copy failed",
    "Copy link": "Copy link",
    "Copy selected": "Copy selected",
    "Copy selected item(s) to:": "Kopioi valitut kohteet:",
    "Copy the IdP's certificate and paste it here. The certificate format is as follows:": "Copy the IdP's certificate and paste it here. The certificate format is as follows:",
    "Copy the domain DNS TXT and add it to your domain's DNS records, then click the button to verify domain ownership. You must verify the ownership of domain before Single Sign-On.": "Copy the domain DNS TXT and add it to your domain's DNS records, then click the button to verify domain ownership. You must verify the ownership of domain before Single Sign-On.",
    "Copy {num} items": "Copy {num} items",
    "Copy {placeholder} to": "Copy {placeholder} to",
    "Copyright Infringement": "Copyright Infringement",
    "Count": "M\u00e4\u00e4r\u00e4",
    "Cover": "Cover",
    "Create": "Luo",
    "Create At": "Luotu",
    "Create Group": "Luo Ryhm\u00e4",
    "Create Library": "Luo Kirjasto",
    "Create Report": "Create Report",
    "Create a DNS TXT record to confirm the ownership of your Email Domain.": "Create a DNS TXT record to confirm the ownership of your Email Domain.",
    "Create a new tag": "Create a new tag",
    "Created": "Luotu",
    "Created At": "Luotu",
    "Created Files": "Created Files",
    "Created draft": "Created draft",
    "Created file": "Created file",
    "Created folder": "Created folder",
    "Created group {group_name}": "Luotu ryhm\u00e4 {group_name}",
    "Created library": "Luotiin kirjasto",
    "Created library {library_name} with {owner} as its owner": "Kirjasto {library_name} luotu omistajana {owner} ",
    "Created time": "Created time",
    "Created {n} files": "Created {n} files",
    "Creator": "Luoja",
    "Current Connected Devices": "Nykyiset Yhdistetyt Laitteet",
    "Current Library": "Nykyinen kirjasto",
    "Current Path: ": "Nykyinen polku:",
    "Current Version": "Nykyinen versio",
    "Current page": "Current page",
    "Current password": "Current password",
    "Current password cannot be blank": "Nykyinen salasana ei voi olla tyhj\u00e4",
    "Current path: ": "Nykyinen polku:",
    "Custom CSS": "Muokattu CSS",
    "Custom properties": "Custom properties",
    "Custom sharing permissions": "Custom sharing permissions",
    "Customize URL": "Customize URL",
    "DNS TXT Value": "DNS TXT Value",
    "Date": "P\u00e4iv\u00e4ys",
    "Date Invalid.": "Date Invalid.",
    "Day": "Day",
    "Default": "Oletus",
    "Delete": "Poista",
    "Delete Account": "Poista tili",
    "Delete Department": "Poista Osasto.",
    "Delete Expired Invitations": "Poista vanhentuneet kutsut",
    "Delete File": "Delete File",
    "Delete Folder": "Delete Folder",
    "Delete Group": "Tuhoa Ryhm\u00e4",
    "Delete Institution": "Poista instituutio",
    "Delete Library": "Tuhoa Kirjasto",
    "Delete Member": "Poista J\u00e4sen",
    "Delete Notification": "Poista ilmoitus",
    "Delete Password": "Delete Password",
    "Delete T&C": "Delete T&C",
    "Delete User": "Poista k\u00e4ytt\u00e4j\u00e4",
    "Delete Users": "Delete Users",
    "Delete WebDAV Password": "Delete WebDAV Password",
    "Delete Wiki": "Poista Wiki",
    "Delete file": "Delete file",
    "Delete files from this device the next time it comes online.": "Poista tiedostot t\u00e4st\u00e4 laitteesta kun se seuraavan kerran tulee verkkoon.",
    "Delete folder": "Delete folder",
    "Delete group": "Delete group",
    "Delete page": "Delete page",
    "Delete property": "Delete property",
    "Delete selected": "Delete selected",
    "Delete share links": "Delete share links",
    "Deleted": "Poistettu",
    "Deleted Libraries": "Poistetut Kirjastot",
    "Deleted Time": "Poistoaika",
    "Deleted directories": "Poistetut hakemistot",
    "Deleted draft": "Deleted draft",
    "Deleted file": "Deleted file",
    "Deleted files": "Poistetut tiedostot",
    "Deleted folder": "Deleted folder",
    "Deleted group {group_name}": "Tuhottu ryhm\u00e4 {group_name}",
    "Deleted library": "Poistettu kirjasto",
    "Deleted library {library_name}": "Poistettu kirjasto {library_name}",
    "Deleted option": "Deleted option",
    "Deleted user %s": "Deleted user %s",
    "Deleted user {user}": "Poistettu k\u00e4ytt\u00e4j\u00e4 {user}",
    "Department renamed": "Department renamed",
    "Departments": "Osastot",
    "Description": "Kuvaus",
    "Description is required": "Kuvaus vaaditaan",
    "Desktop": "Desktop",
    "Detail": "Selite",
    "Details": "Yksityiskohdat",
    "Device": "Laite",
    "Device Name": "Laitteen nimi",
    "Device make": "Device make",
    "Device model": "Device model",
    "Devices": "Laitteet",
    "Dimensions": "Dimensions",
    "Direct download link": "Direct download link",
    "Direct download link is copied to the clipboard.": "Direct download link is copied to the clipboard.",
    "Disable Two-Factor Authentication": "Poista kaksisuuntainen tunnistautuminen k\u00e4yt\u00f6st\u00e4",
    "Disconnect": "Disconnect",
    "Discussion": "Keskustelu",
    "Display files": "Display files",
    "Do not automatically delete files": "Do not automatically delete files",
    "Do you really want to turn off extended properties? Existing properties will all be deleted.": "Do you really want to turn off extended properties? Existing properties will all be deleted.",
    "Document": "Document",
    "Document conversion failed.": "Document conversion failed.",
    "Document keywords": "Document keywords",
    "Domain verified": "Domain verified",
    "Don't ignore": "Don't ignore",
    "Don't keep history": "\u00c4l\u00e4 pid\u00e4 historiaa",
    "Don't replace": "\u00c4l\u00e4 korvaa",
    "Don't send emails": "Don't send emails",
    "Done": "Done",
    "Down": "Down",
    "Download": "Lataa",
    "Download an example file": "Lataa esimerkkitiedosto",
    "Download and upload": "Download and upload",
    "Duplicate": "Duplicate",
    "Duplicate page": "Duplicate page",
    "Edit": "Muokkaa",
    "Edit format settings": "Edit format settings",
    "Edit labels": "Muokkaa etikettej\u00e4",
    "Edit metadata properties": "Edit metadata properties",
    "Edit multiple select": "Edit multiple select",
    "Edit on cloud and download": "Muokkaa pilvess\u00e4 ja lataa",
    "Edit on cloud only": "Edit on cloud only",
    "Edit permission": "Edit permission",
    "Edit single select": "Edit single select",
    "Edit succeeded": "Muokkaus onnistui",
    "Edit succeeded.": "Edit succeeded.",
    "Email": "S\u00e4hk\u00f6posti",
    "Email Domain": "Email Domain",
    "Email Notification": "Email Notification",
    "Email is invalid.": "Email is invalid.",
    "Email notification updated": "Email notification updated",
    "Emails": "Emails",
    "Emails, separated by ','": "S\u00e4hk\u00f6postit, erotellaan ',' merkill\u00e4",
    "Emojis": "Emojis",
    "Empty": "Tyhj\u00e4",
    "Enable Two-Factor Authentication": "Ota k\u00e4ytt\u00f6\u00f6n Kaksisuuntainen Tunnistautuminen",
    "Enable extended properties": "Enable extended properties",
    "Enable face recognition to identify people in your photos.": "Enable face recognition to identify people in your photos.",
    "Enable system admin to add Terms and Conditions, and all users will have to accept the terms.": "Anna j\u00e4rjestelm\u00e4nvalvojan ottaa k\u00e4ytt\u00f6\u00f6n ehdot ja edellytykset ja kaikkien k\u00e4ytt\u00e4jien on hyv\u00e4ksytt\u00e4v\u00e4 ehdot.",
    "Enable two factor authentication": "Ota k\u00e4ytt\u00f6\u00f6n kaksisuuntainen tunnistautuminen",
    "Enable users to share libraries to any groups in the system.": "Salli k\u00e4ytt\u00e4jien jakaa kirjastoja kaikille systeemin ryhmille.",
    "Encrypt": "Salattu",
    "Encrypted library": "Salattu kirjasto",
    "End date": "End date",
    "Enter characters to start searching": "Enter characters to start searching",
    "Error": "Virhe",
    "Errors": "Virheet",
    "European": "European",
    "Exact date": "Exact date",
    "Exit Institution Admin": "Exit Institution Admin",
    "Exit Organization Admin": "Exit Organization Admin",
    "Exit System Admin": "Pois j\u00e4rjestelm\u00e4n hallinnasta",
    "Expand all": "Expand all",
    "Expiration": "P\u00e4\u00e4ttyminen",
    "Expiration days": "Expiration days",
    "Expiration time": "Expiration time",
    "Expired": "Vanhentunut",
    "Expired at": "Vanhentunut",
    "Export": "Export",
    "Export Excel": "Vie Exceliin",
    "Export as docx": "Export as docx",
    "Export as zip": "Export as zip",
    "Export tags": "Export tags",
    "Exporting": "Exporting",
    "Exporting...": "Exporting...",
    "Exposure time": "Exposure time",
    "Extended properties": "Extended properties",
    "Extension Prompts": "Extension Prompts",
    "Extensions of text files that can be online previewed, each suffix is separated by a comma.": "Tekstitiedostojen laajennukset joita voi esikatsella verkossa, jokainen j\u00e4lkiliite erotetaan pilkulla.",
    "Extract file detail": "Extract file detail",
    "Extract file details": "Extract file details",
    "F number": "F number",
    "Face recognition": "Face recognition",
    "Failed": "Ep\u00e4onnistui",
    "Failed imported options": "Failed imported options",
    "Failed to convert {name}.": "Failed to convert {name}.",
    "Failed to copy %(name)s": "%(name)s kopiointi ep\u00e4onnistui.",
    "Failed to copy %(name)s and %(amount)s other item(s).": "Failed to copy %(name)s and %(amount)s other item(s).",
    "Failed to copy %(name)s.": "Failed to copy %(name)s.",
    "Failed to copy files to another library.": "Failed to copy files to another library.",
    "Failed to delete %(virus_file) from library %(library): %(error_msg)": "Failed to delete %(virus_file) from library %(library): %(error_msg)",
    "Failed to delete property": "Failed to delete property",
    "Failed to delete records": "Failed to delete records",
    "Failed to delete {name}": "Failed to delete {name}",
    "Failed to delete {name} and {n} other items.": "Failed to delete {name} and {n} other items.",
    "Failed to delete {name}.": "Failed to delete {name}.",
    "Failed to download. The total size of the files exceeded the limit.": "Failed to download. The total size of the files exceeded the limit.",
    "Failed to duplicate page": "Failed to duplicate page",
    "Failed to export. Please check whether the size of table attachments exceeds the limit.": "Failed to export. Please check whether the size of table attachments exceeds the limit.",
    "Failed to extract file details": "Failed to extract file details",
    "Failed to generate description": "Failed to generate description",
    "Failed to ignore %(virus_file) from library %(library): %(error_msg)": "Failed to ignore %(virus_file) from library %(library): %(error_msg)",
    "Failed to insert property": "Failed to insert property",
    "Failed to modify filter": "Failed to modify filter",
    "Failed to modify group": "Failed to modify group",
    "Failed to modify hidden properties": "Failed to modify hidden properties",
    "Failed to modify people name": "Failed to modify people name",
    "Failed to modify property data": "Failed to modify property data",
    "Failed to modify property order": "Failed to modify property order",
    "Failed to modify records": "Failed to modify records",
    "Failed to modify sort": "Failed to modify sort",
    "Failed to move %(name)s and %(amount)s other item(s).": "Failed to move %(name)s and %(amount)s other item(s).",
    "Failed to move %(name)s.": "Failed to move %(name)s.",
    "Failed to move files to another library.": "Failed to move files to another library.",
    "Failed to move {name}.": "Failed to move {name}.",
    "Failed to rename property": "Failed to rename property",
    "Failed to restore records": "Failed to restore records",
    "Failed to restore {name}": "Failed to restore {name}",
    "Failed to restore {name} and {n} other items": "Failed to restore {name} and {n} other items",
    "Failed to save": "Failed to save",
    "Failed to send to {email_placeholder}: {errorMsg_placeholder}": "Failed to send to {email_placeholder}: {errorMsg_placeholder}",
    "Failed to unshare {name}": "Failed to unshare {name}",
    "Failed to upload {file_name}.": "Failed to upload {file_name}.",
    "Failed. Please check the network.": "Ep\u00e4onnistui. Ole hyv\u00e4 ja tarkista verkkoyhteys.",
    "Favorites": "Suosikit",
    "File": "Tiedosto",
    "File Access": "Tiedoston k\u00e4ytt\u00f6oikeudet",
    "File Operations": "Tiedosto Operaatiot",
    "File Update": "Tiedosto p\u00e4ivitys",
    "File Upload": "Tiedoston l\u00e4hett\u00e4minen ",
    "File Uploading...": "Tiedostoa l\u00e4hetet\u00e4\u00e4n...",
    "File already exists.": "File already exists.",
    "File collaborators": "File collaborators",
    "File details": "File details",
    "File download is disabled: the share link traffic of owner is used up.": "Tiedoston lataus on suljettu: linkin omistajan kaista on t\u00e4ynn\u00e4.",
    "File expire time": "File expire time",
    "File extension white list": "File extension white list",
    "File extension white list for file upload via web UI and API. For example, \"md;txt;docx\". Empty means no limit.": "File extension white list for file upload via web UI and API. For example, \"md;txt;docx\". Empty means no limit.",
    "File extensions can only be {placeholder}.": "File extensions can only be {placeholder}.",
    "File is locked by others.": "File is locked by others.",
    "File name": "File name",
    "File owner": "File owner",
    "File reviewer": "File reviewer",
    "File size is too large.": "File size is too large.",
    "File status": "File status",
    "File too large": "File too large",
    "File type": "File type",
    "Files": "Tiedostot",
    "Files and folders": "Files and folders",
    "Filter": "Filter",
    "Filters": "Filters",
    "Find a tag": "Find a tag",
    "Find modifiers": "Find modifiers",
    "Focal length": "Focal length",
    "Folder": "Hakemisto",
    "Folder Permission": "Hakemiston oikeudet",
    "Folder does not exist.": "Folder does not exist.",
    "Folders": "Hakemistot",
    "Force user to change password when account is newly added or reset by admin": "Pakota k\u00e4ytt\u00e4j\u00e4n vaihtamaan salasana jos tili on juuri lis\u00e4tty tai resetoitu j\u00e4rjestelm\u00e4nvalvojan toimesta ",
    "Force user to use a strong password when sign up or change password.": "Pakota k\u00e4ytt\u00e4m\u00e4\u00e4n vahvaa salasanaa tili\u00e4 tehdess\u00e4 tai kun salasanaa vaihdetaan.",
    "Format": "Format",
    "Freeze Document": "Freeze Document",
    "Freeze user account when failed login attempts exceed limit.": "J\u00e4\u00e4dyt\u00e4 k\u00e4ytt\u00e4j\u00e4tili liian monen ep\u00e4onnistuneen kirjautumisyrityksen j\u00e4lkeen.",
    "Frozen by {name}": "Frozen by {name}",
    "Gallery": "Gallery",
    "General information": "General information",
    "Generate": "Luo",
    "Generate Link": "Generate Link",
    "Generate description": "Generate description",
    "Generate links in batch": "Generate links in batch",
    "Generate share link": "Generate share link",
    "Germany Russia etc": "Germany Russia etc",
    "Global Address Book": "Globaali Osoitekirja",
    "Greater than or equal to {minDays_placeholder} days": "Greater than or equal to {minDays_placeholder} days",
    "Grid view": "Grid view",
    "Group": "Ryhm\u00e4",
    "Group Permission": "Ryhm\u00e4n oikeudet",
    "Group Shares": "Group Shares",
    "Group by": "Group by",
    "Group members": "Group members",
    "Grouped by 1 property": "Grouped by 1 property",
    "Groups": "Ryhm\u00e4t",
    "Guest": "Vieras",
    "Handled": "K\u00e4sitelty",
    "Help": "Tuki",
    "Hide": "Piilota",
    "Hide all": "Hide all",
    "Hide properties": "Hide properties",
    "History": "Historia",
    "History Setting": "Historian asetukset",
    "History Versions": "History Versions",
    "IP": "IP",
    "ISO": "ISO",
    "If notifications have not been read within one hour, they will be sent to your mailbox.": "If notifications have not been read within one hour, they will be sent to your mailbox.",
    "If turn on, the desktop clients will not be able to sync a folder outside the default Seafile folder.": "Jos valittuna, ty\u00f6asema asiakasohjelmat eiv\u00e4t voi synkronoida kansioita Seafile oletuskansio ulkopuolelta.",
    "If you don't have any device with you, you can access your account using backup codes.": "Jos teill\u00e4 ei ole mit\u00e4\u00e4n laitteita mukana, voit p\u00e4\u00e4st\u00e4 k\u00e4ytt\u00e4m\u00e4\u00e4n tili\u00e4si varakoodeilla.",
    "Ignore": "Ignore",
    "Ignored": "Ignored",
    "Import Users": "Import Users",
    "Import members": "Import members",
    "Import members from a .xlsx file": "Import members from a .xlsx file",
    "Import options": "Import options",
    "Import sdoc": "Import sdoc",
    "Import tags": "Import tags",
    "Import users": "Tuo k\u00e4ytt\u00e4ji\u00e4",
    "Import users from a .xlsx file": "Tuo k\u00e4ytt\u00e4ji\u00e4 .xlsx tiedostosta",
    "In progress": "In progress",
    "In review": "In review",
    "Inactive": "Ei aktiivinen",
    "Info": "Info",
    "Institution Admin": "Institution Admin",
    "Institutions": "Instituutiot",
    "Internal Link": "Internal Link",
    "Internal Server Error": "Sis\u00e4inen palvelinvirhe",
    "Internal link has been copied to clipboard": "Internal link has been copied to clipboard",
    "Invalid destination path": "Virheellinen kohdepolku",
    "Invalid filename.": "Invalid filename.",
    "Invalid filter": "Invalid filter",
    "Invalid month, should be yyyymm.": "Invalid month, should be yyyymm.",
    "Invalid regular expression": "Invalid regular expression",
    "Invisible": "Invisible",
    "Invitations": "Kutsut",
    "Invite Guest": "Invite Guest",
    "Invite Time": "Kutsu Aika",
    "Invite users": "Invite users",
    "Invited at": "Kutsuttu",
    "Inviter": "Kutsuja",
    "Is expired": "Is expired",
    "It is required.": "Vaaditaan",
    "It may take some time, please wait.": "It may take some time, please wait.",
    "Keep full history": "Pid\u00e4 t\u00e4ysi historia",
    "Keep sharing": "Keep sharing",
    "LDAP": "LDAP",
    "LDAP(imported)": "LDAP(tuotu)",
    "Label": "Label",
    "Label Current State": "Label Current State",
    "Labels": "Etiketit",
    "Language": "Kieli",
    "Language Setting": "Kieliasetus",
    "Last Access": "Viimeisin k\u00e4ytt\u00f6",
    "Last Login": "Viimeisin kirjautuminen",
    "Last Update": "Viimeisin p\u00e4ivitys",
    "Last modified by": "Last modified by",
    "Last modified time": "Last modified time",
    "Last modifier": "Last modifier",
    "Leave": "Leave",
    "Leave Group": "Leave Group",
    "Leave Share": "Poistu jaosta",
    "Leave group": "Poistu ryhm\u00e4st\u00e4",
    "Leave this page? The system may not save your changes.": "Leave this page? The system may not save your changes.",
    "Less than or equal to {maxDays_placeholder} days": "Less than or equal to {maxDays_placeholder} days",
    "Libraries": "Kirjastot",
    "Library": "Kirjasto",
    "Library Type": "Kirjaston tyyppi",
    "Library does not exist": "Kirjastoa ei ole",
    "Limits": "Rajat",
    "Link": "Linkki",
    "Link has been copied to clipboard": "Link has been copied to clipboard",
    "Linked Devices": "Yhdistetyt Laitteet",
    "Links": "Linkit",
    "List view": "List view",
    "List your account in global address book, so that others can find you by typing your name.": "Listaa tilisi globaalissa osoitelistassa, jotta muut l\u00f6yt\u00e4v\u00e4t teid\u00e4t kirjoittamalla nimenne.",
    "Load all": "Load all",
    "Loading": "Loading",
    "Loading...": "Ladataan...",
    "Location": "Sijainti",
    "Lock": "Lukitse",
    "Log out": "Kirjaudu ulos",
    "Login": "Login",
    "Login ID": "Login ID",
    "Logo updated": "Logo updated",
    "Logs": "Logi",
    "Long text": "Long text",
    "Manage group members": "Manage group members",
    "Manage members": "Manage members",
    "Mark all read": "Merkitse kaikki luetuksi",
    "Max": "Max",
    "Max number of members": "Max number of members",
    "Member": "J\u00e4sen",
    "Members": "J\u00e4senet",
    "Message": "Viesti",
    "Message (optional):": "Viesti (valinnainen)",
    "Migrate User": "Migrate User",
    "Mobile": "Mobile",
    "Modification Details": "Muokkauksen yksityiskohdat",
    "Modified": "Muokattu",
    "Modified by": "Modified by",
    "Modified by:": "Modified by:",
    "Modified files": "Muokatut tiedostot",
    "Modifier": "Muokkaaja",
    "Modify": "Modify",
    "Modify includes modify file, move/rename file and folder": "Modify includes modify file, move/rename file and folder",
    "Modify name": "Modify name",
    "Month": "Month",
    "Month:": "Kuukausi:",
    "Monthly User Traffic": "Monthly User Traffic",
    "More": "Lis\u00e4\u00e4",
    "More operations": "Lis\u00e4\u00e4 operaatioita",
    "Move": "Siirr\u00e4",
    "Move selected item(s) to:": "Siirr\u00e4 valitut kohteet:",
    "Move {num} items": "Move {num} items",
    "Move {placeholder} to": "Move {placeholder} to",
    "Moved file": "Moved file",
    "Moved folder": "Moved folder",
    "Multiple select": "Multiple select",
    "My Libraries": "Minun Kirjastot",
    "My Wikis": "My Wikis",
    "Name": "Nimi",
    "Name already exists": "Name already exists",
    "Name cannot be double dots": "Name cannot be double dots",
    "Name cannot be empty": "Name cannot be empty",
    "Name cannot contain backslash": "Name cannot contain backslash",
    "Name cannot contain backtick": "Name cannot contain backtick",
    "Name cannot contain curly braces": "Name cannot contain curly braces",
    "Name cannot contain dots": "Name cannot contain dots",
    "Name cannot contain slash": "Name cannot contain slash",
    "Name is required": "Nimi vaaditaan",
    "Name is required.": "Nimi vaaditaan.",
    "Name or ID": "Name or ID",
    "Name should be string": "Name should be string",
    "Name should not include '/'.": "Nimi ei voi sis\u00e4lt\u00e4\u00e4 '/'",
    "Name updated": "Name updated",
    "Name(optional)": "Nimi(valinnainen)",
    "Network error": "Verkkovirhe",
    "New": "Uusi",
    "New Department": "Uusi Osasto",
    "New Department Library": "Uusi Osastokirjasto",
    "New Excel File": "Uusi Excel tiedosto",
    "New File": "Uusi Tiedosto",
    "New Folder": "Uusi Hakemisto",
    "New Group": "Uusi ryhm\u00e4",
    "New Library": "Uusi Kirjasto",
    "New Markdown File": "Uusi Markdown tiedosto",
    "New Password": "Uusi salasana",
    "New Password Again": "Uusi salasana uudestaan",
    "New PowerPoint File": "Uusi PowerPoint tiedosto",
    "New SeaDoc File": "New SeaDoc File",
    "New Sub-department": "Uusi Aliosasto",
    "New Word File": "Uusi Word tiedosto",
    "New directories": "Uudet hakemistot",
    "New file name": "New file name",
    "New files": "Uudet tiedostot",
    "New folder name": "New folder name",
    "New page": "New page",
    "New password": "Uusi salasana",
    "New password cannot be the same as old password": "New password cannot be the same as old password",
    "New password has been sent to your email {mail}. Please check your mailbox. If you don\u2019t receive the password, please check if your email address is properly configured.": "New password has been sent to your email {mail}. Please check your mailbox. If you don\u2019t receive the password, please check if your email address is properly configured.",
    "New password is too short": "Uusi salasana on liian lyhyt",
    "New passwords don't match": "Uudet salasanat eiv\u00e4t t\u00e4sm\u00e4\u00e4",
    "New view": "New view",
    "Next": "Seuraava",
    "Next (Right arrow key)": "Seuraava (Oikea nuolin\u00e4pp\u00e4in)",
    "No Admin login logs": "No Admin login logs",
    "No Admin operation logs": "No Admin operation logs",
    "No Wikis": "No Wikis",
    "No changes": "No changes",
    "No collaborators": "No collaborators",
    "No collaborators available": "No collaborators available",
    "No comment yet.": "Ei kommentteja viel\u00e4.",
    "No connected devices": "Ei yhdistettyj\u00e4 laitteita",
    "No deleted libraries": "No deleted libraries",
    "No favorites": "No favorites",
    "No file": "No file",
    "No file access logs": "No file access logs",
    "No file update logs": "No file update logs",
    "No filters": "No filters",
    "No folders shared": "No folders shared",
    "No groupings applied to this view.": "No groupings applied to this view.",
    "No groups": "Ei ryhmi\u00e4",
    "No guest invitations": "No guest invitations",
    "No invitations": "No invitations",
    "No libraries": "Ei kirjastoja",
    "No libraries have been shared directly with you. A shared library can be shared with full or restricted permission. If you need access to a library owned by another user, ask the user to share the library with you.": "No libraries have been shared directly with you. A shared library can be shared with full or restricted permission. If you need access to a library owned by another user, ask the user to share the library with you.",
    "No libraries have been shared with you": "Sinun kanssasi ei ole jaettu kirjastoja",
    "No libraries have been shared with you from other servers.": "No libraries have been shared with you from other servers.",
    "No libraries shared": "No libraries shared",
    "No libraries shared with this group": "No libraries shared with this group",
    "No linked devices": "No linked devices",
    "No linked devices. You have not accessed your files with any client (desktop or mobile) yet. Configure clients on your devices to access your data more comfortably.": "No linked devices. You have not accessed your files with any client (desktop or mobile) yet. Configure clients on your devices to access your data more comfortably.",
    "No login logs": "No login logs",
    "No members": "Ei j\u00e4seni\u00e4",
    "No more activities": "No more activities",
    "No notifications": "No notifications",
    "No option": "No option",
    "No options": "No options",
    "No options available": "No options available",
    "No permission logs": "No permission logs",
    "No properties available to be hidden": "No properties available to be hidden",
    "No public libraries": "Ei julkisia kirjastoja",
    "No record": "No record",
    "No result": "Ei tulosta",
    "No results": "No results",
    "No results matching": "No results matching",
    "No share links": "No share links",
    "No sync errors": "Ei synkronointi virheit\u00e4",
    "No tags": "No tags",
    "No terms and conditions": "No terms and conditions",
    "No upload links": "No upload links",
    "No version history": "No version history",
    "None": "Ei mit\u00e4\u00e4n",
    "Not allow user to clean library trash": "Not allow user to clean library trash",
    "Not allow user to create encrypted libraries": "Not allow user to create encrypted libraries",
    "Note: Settings via web interface are saved in database table (seahub-db/constance_config). They have a higher priority over the settings in config files.": "Huom: Web sivuston kautta tehdyt asetukset tallennetaan tietokannan (seahub-db/constance_config) tauluun. N\u00e4ill\u00e4 asetuksilla on suurempi prioriteetti kuin config tiedostoissa olevilla asetuksilla.",
    "Notification Detail": "Ilmoituksen sis\u00e4lt\u00f6",
    "Notifications": "Ilmoitukset",
    "Notifications of file changes": "Notifications of file changes",
    "Number": "Number",
    "Number of days ago": "Number of days ago",
    "Number of days from now": "Number of days from now",
    "Number of days that keep user sign in.": "P\u00e4ivien m\u00e4\u00e4r\u00e4 jona pidet\u00e4\u00e4n k\u00e4ytt\u00e4j\u00e4 sis\u00e4\u00e4nkirjautuneena.",
    "Number of groups": "Ryhmien m\u00e4\u00e4r\u00e4",
    "Number of links": "Number of links",
    "Number of members": "J\u00e4senien m\u00e4\u00e4r\u00e4",
    "Off": "Off",
    "Old Password": "Vanha salasana",
    "Old Wikis": "Old Wikis",
    "On": "On",
    "One month ago": "One month ago",
    "One month from now": "One month from now",
    "One week ago": "One week ago",
    "One week from now": "One week from now",
    "Online Preview": "Online esikatselu",
    "Online Read-Only": "Online Read-Only",
    "Online Read-Only folder": "Online Read-Only folder",
    "Online Read-Only library": "Online Read-Only library",
    "Online Read-Write": "Online Read-Write",
    "Online Read-Write folder": "Online Read-Write folder",
    "Online Read-Write library": "Online Read-Write library",
    "Online view is not applicable to this file format": "Online view is not applicable to this file format",
    "Only Show": "N\u00e4yt\u00e4 vain",
    "Only files": "Only files",
    "Only folders": "Only folders",
    "Only keep a period of history:": "Pid\u00e4 historia ainoastaan tietyn ajan:",
    "Only pictures": "Only pictures",
    "Only videos": "Only videos",
    "Open file": "Open file",
    "Open file in new tab": "Open file in new tab",
    "Open folder": "Open folder",
    "Open folder in new tab": "Open folder in new tab",
    "Open in new tab": "Open in new tab",
    "Open parent folder": "Avaa is\u00e4nt\u00e4kansio",
    "Open via Client": "Avaa asiakasohjelmassa",
    "Operation": "Toimenpide",
    "Operation succeeded.": "Operaatio onnistui.",
    "Operations": "Toiminnot",
    "Optional": "Valinnainen",
    "Options imported": "Options imported",
    "Or": "Or",
    "Organization": "Organisaatio",
    "Organization Admin": "Organisaation hallinnoija",
    "Organizations": "Organisaatiot",
    "Original path": "Original path",
    "Other": "Other",
    "Other Libraries": "Muut kirjastot",
    "Others": "Others",
    "Out of quota.": "Tila loppu.",
    "Outdated": "Outdated",
    "Owned Libraries": "Owned Libraries",
    "Owner": "Omistaja",
    "Owner can use admin panel in an organization, must be a new account.": "Omistaja voi k\u00e4ytt\u00e4\u00e4 organisaation yll\u00e4pitopaneelia, t\u00e4ytyy olla uusi tili.",
    "Packaging...": "Pakataan...",
    "Page name": "Page name",
    "Pages": "Sivut",
    "Parent folder": "Parent folder",
    "Password": "Salasana",
    "Password again": "Salasana uudestaan",
    "Password cannot be blank": "Salasana ei voi olla tyhj\u00e4",
    "Password is too short": "Salasana on liian lyhyt",
    "Password must be at least 8 characters long and contain different characters: uppercase letters, lowercase letters, numbers, and special symbols": "Password must be at least 8 characters long and contain different characters: uppercase letters, lowercase letters, numbers, and special symbols",
    "Password removed": "Password removed",
    "Password reset": "Password reset",
    "Password set": "Password set",
    "Password strength": "Password strength",
    "Password updated": "Password updated",
    "Passwords do not match.": "Passwords do not match.",
    "Passwords don't match": "Salasanat eiv\u00e4t t\u00e4sm\u00e4\u00e4",
    "Path": "Path",
    "Per 4 hours": "Per 4 hours",
    "Per day": "Per day",
    "Per hour": "Per hour",
    "Per week": "Per week",
    "Permission": "Oikeus",
    "Permission denied": "Lupa ev\u00e4tty",
    "Permission denied. Please try {placeholder-left}login again.{placeholder-right}": "Permission denied. Please try {placeholder-left}login again.{placeholder-right}",
    "Permission name": "Permission name",
    "Person image": "Person image",
    "Picture": "Picture",
    "Pictures and videos": "Pictures and videos",
    "Platform": "Alusta",
    "Please check the network.": "Ole hyv\u00e4 ja tarkista verkko.",
    "Please choose a .xlsx file.": "Ole hyv\u00e4 ja valitse .xlsx tiedosto.",
    "Please choose an image file.": "Please choose an image file.",
    "Please enter 1 or more character": "Ole hyv\u00e4 ja sy\u00f6t\u00e4 1 tai useampi merkki",
    "Please enter a new password": "Ole hyv\u00e4 ja anna uusi salasana",
    "Please enter a non-negative integer": "Please enter a non-negative integer",
    "Please enter a password.": "Please enter a password.",
    "Please enter a positive integer": "Please enter a positive integer",
    "Please enter an integer bigger than 1 as number of links.": "Please enter an integer bigger than 1 as number of links.",
    "Please enter an integer not bigger than {max_number} as number of links.": "Please enter an integer not bigger than {max_number} as number of links.",
    "Please enter days": "Ole hyv\u00e4 ja sy\u00f6t\u00e4 p\u00e4iv\u00e4t",
    "Please enter password": "Ole hyv\u00e4 ja sy\u00f6t\u00e4 salasana",
    "Please enter the new password again": "Ole hyv\u00e4 ja anna uusi salasana uudelleen",
    "Please enter the old password": "Ole hyv\u00e4 ja anna vanha salasana",
    "Please enter the password again": "Ole hyv\u00e4 ja sy\u00f6t\u00e4 salasana uudelleen",
    "Please input at least an email.": "Ole hyv\u00e4 ja sy\u00f6t\u00e4 ainakin s\u00e4hk\u00f6posti.",
    "Please select a file": "Please select a file",
    "Please select a library to share.": "Please select a library to share.",
    "Please select an expiration time": "Please select an expiration time",
    "Please upload no more than {maxFiles} files at a time.": "Please upload no more than {maxFiles} files at a time.",
    "Preset hide properties": "Preset hide properties",
    "Preview and download": "Esikatsele ja lataa",
    "Preview online": "Preview online",
    "Preview only": "Esikatselu ainoastaan",
    "Previous": "J\u00e4lkimm\u00e4inen",
    "Previous (Left arrow key)": "Edellinen (Vasen nuolin\u00e4pp\u00e4in)",
    "Print": "Print",
    "Professional Edition": "Professional Edition",
    "Profile": "Profiili",
    "Profile Setting": "Profiilin asetus",
    "Properties": "Properties",
    "Property name": "Property name",
    "Publish": "Publish",
    "Publish Wiki": "Publish Wiki",
    "Quota": "Kiinti\u00f6",
    "Quota is invalid.": "Quota is invalid.",
    "Rate": "Rate",
    "Read-Only": "Vain-Luku",
    "Read-Only folder": "Read-Only folder",
    "Read-Only library": "Vain luku kirjasto",
    "Read-Write": "Luku-Kirjoitus",
    "Read-Write folder": "Read-Write folder",
    "Read-Write library": "Luku-kirjoitus kirjasto",
    "Really want to delete this group?": "Really want to delete this group?",
    "Really want to delete your account?": "Haluatko varmasti poistaa tilin?",
    "Really want to leave this group?": "Really want to leave this group?",
    "Recognizing portraits. Please refresh the page later.": "Recognizing portraits. Please refresh the page later.",
    "Refresh": "P\u00e4ivit\u00e4",
    "Remove": "Poista",
    "Rename": "Nime\u00e4 uudelleen",
    "Rename Department": "Rename Department",
    "Rename File": "Nime\u00e4 tiedosto uudelleen",
    "Rename Folder": "Nime\u00e4 kansio uudelleen",
    "Rename Group": "Rename Group",
    "Rename Wiki": "Rename Wiki",
    "Rename file": "Rename file",
    "Rename folder": "Rename folder",
    "Rename group to": "Rename group to",
    "Rename property": "Rename property",
    "Renamed file": "Renamed file",
    "Renamed folder": "Renamed folder",
    "Renamed library": "Renamed library",
    "Renamed or Moved files": "Uudelleen nimetyt tai siirretyt tiedostot",
    "Renaming {name} failed": "Renaming {name} failed",
    "Replace": "Korvaa",
    "Replace file {filename}?": "Korvaa tiedosto {filename}?",
    "Replacing it will overwrite its content.": "Korvaaminen kirjoittaa sis\u00e4ll\u00f6n yli.",
    "Report Abuse": "Report Abuse",
    "Reporter": "Reporter",
    "Reports": "Reports",
    "Required at least three letters.": "Required at least three letters.",
    "Reset": "Reset",
    "Reset Password": "Nollaa salasana",
    "Reset WebDAV Password": "Reset WebDAV Password",
    "Reset library password": "Reset library password",
    "ResetPwd": "Nollaa salasana",
    "Resetting user's password, please wait for a moment.": "Resetting user's password, please wait for a moment.",
    "Restore": "Palauta",
    "Restore Library": "Palauta Kirjasto",
    "Restored file": "Restored file",
    "Restored folder": "Restored folder",
    "Restored library": "Restored library",
    "Restored {name}": "Restored {name}",
    "Restored {name} and {n} other items": "Restored {name} and {n} other items",
    "Result": "Tulos",
    "Revoke Access": "Revoke Access",
    "Revoke Admin": "Kumoa yll\u00e4pit\u00e4j\u00e4",
    "Role": "Rooli",
    "SAML config": "SAML config",
    "SAML config updated": "SAML config updated",
    "Save": "Save",
    "Save Selected Items": "Save Selected Items",
    "Save to:": "Save to:",
    "Saving...": "Tallennetaan...",
    "Scan the QR code to view the shared content directly": "Scan the QR code to view the shared content directly",
    "SeaTable integration": "SeaTable integration",
    "Seafile": "Seafile",
    "Search": "Search",
    "Search Groups": "Search Groups",
    "Search Libraries": "Search Libraries",
    "Search Organizations": "Search Organizations",
    "Search Users": "Search Users",
    "Search collaborator": "Search collaborator",
    "Search collaborators": "Search collaborators",
    "Search files": "Search files",
    "Search files in this library": "Etsi tiedostoja t\u00e4st\u00e4 kirjastosta",
    "Search groups": "Etsi ryhmi\u00e4",
    "Search groups by name": "Search groups by name",
    "Search libraries by name or ID": "Search libraries by name or ID",
    "Search libraries by owner": "Search libraries by owner",
    "Search option": "Search option",
    "Search organizations": "Search organizations",
    "Search property": "Search property",
    "Search users": "Search users",
    "Search users...": "Etsi k\u00e4ytt\u00e4ji\u00e4...",
    "Searching...": "Etsit\u00e4\u00e4n...",
    "Select File": "Select File",
    "Select a department": "Select a department",
    "Select a user": "Select a user",
    "Select a user as admin": "Select a user as admin",
    "Select all": "Select all",
    "Select an option": "Select an option",
    "Select collaborators": "Select collaborators",
    "Select libraries to share": "Valitse jaettavat kirjastot",
    "Select option(s)": "Select option(s)",
    "Select up to 50 files": "Select up to 50 files",
    "Send": "L\u00e4het\u00e4",
    "Send activation Email after user registration.": "L\u00e4het\u00e4 aktivointis\u00e4hk\u00f6posti k\u00e4ytt\u00e4j\u00e4n rekister\u00f6itymisen j\u00e4lkeen.",
    "Send to:": "L\u00e4het\u00e4 kohteeseen:",
    "Sending new password...": "Sending new password...",
    "Sending...": "L\u00e4hett\u00e4\u00e4...",
    "Server Version: ": "Palvelimen versio:",
    "Set Admin": "Aseta p\u00e4\u00e4k\u00e4ytt\u00e4j\u00e4",
    "Set Contact Email": "Set Contact Email",
    "Set Download Rate Limit": "Set Download Rate Limit",
    "Set Login ID": "Set Login ID",
    "Set Name": "Set Name",
    "Set Password": "Set Password",
    "Set Quota": "Aseta kiinti\u00f6",
    "Set Upload Rate Limit": "Set Upload Rate Limit",
    "Set WebDAV Password": "Set WebDAV Password",
    "Set max number of members": "Set max number of members",
    "Set password": "Set password",
    "Set permission": "Aseta oikeudet",
    "Set permission of {placeholder}": "Set permission of {placeholder}",
    "Set quota": "Aseta kiinti\u00f6",
    "Set to current": "Aseta nykyiseksi",
    "Set user contact email": "Aseta k\u00e4ytt\u00e4j\u00e4n s\u00e4hk\u00f6posti yhteystieto",
    "Set user default quota": "Set user default quota",
    "Set user name": "Aseta k\u00e4ytt\u00e4j\u00e4tunnus",
    "Set user quota": "Set user quota",
    "Setting library history is disabled by Admin.": "Setting library history is disabled by Admin.",
    "Settings": "Asetukset",
    "Share": "Jaa",
    "Share Admin": "Jakojen hallinta",
    "Share From": "Jaettu kohteesta",
    "Share Link": "Jakolinkki",
    "Share Links": "Jakolinkit",
    "Share To": "Jaa",
    "Share To:": "Share To:",
    "Share existing libraries": "Jaa olemassa olevia kirjastoja",
    "Share link download": "Share link download",
    "Share link is copied to the clipboard.": "Share link is copied to the clipboard.",
    "Share link upload": "Share link upload",
    "Share links cannot be generated because \"Invisible\", \"Online Read-Write\" or \"Online Read-Only\" is set for you on some folder(s) in the library.": "Share links cannot be generated because \"Invisible\", \"Online Read-Write\" or \"Online Read-Only\" is set for you on some folder(s) in the library.",
    "Share to group": "Jaa ryhm\u00e4lle",
    "Share to other server": "Share to other server",
    "Share to user": "Jaa k\u00e4ytt\u00e4j\u00e4lle",
    "Shared By": "Jakaja",
    "Shared Libraries": "Shared Libraries",
    "Shared Links": "Jaetut linkit",
    "Shared by: ": "Jakaja:",
    "Shared with all": "Jaettu kaikille",
    "Shared with me": "Jaettu minulle",
    "Show": "N\u00e4yt\u00e4",
    "Show Codes": "N\u00e4yt\u00e4 Koodit",
    "Show all": "Show all",
    "Show changes": "Show changes",
    "Side Nav Menu": "Sivu Navigointi -valikko",
    "Single select": "Single select",
    "Site name used in email sending": "K\u00e4ytet\u00e4\u00e4n sivuston nime\u00e4 s\u00e4hk\u00f6postin l\u00e4hetyksess\u00e4",
    "Site title shown in a browser tab": "Sivuston titteli n\u00e4ytet\u00e4\u00e4n selaimen v\u00e4lisivulla.",
    "Size": "Koko",
    "Sort": "Sort",
    "Sort ascending": "Sort ascending",
    "Sort descending": "Sort descending",
    "Space Used": "Tilaa k\u00e4ytetty",
    "Space Used / Quota": "K\u00e4ytetty Tila / Kiinti\u00f6",
    "Specific people with email address": "Specific people with email address",
    "Specific users in the team": "Specific users in the team",
    "Star": "Star",
    "Start date": "Start date",
    "Statistic": "Tilastot",
    "Status": "Tila",
    "Status: enabled": "Status: enabled",
    "Storage": "Tila",
    "Storage Backend": "Storage Backend",
    "Storage Used": "K\u00e4ytetty tila",
    "Style": "Style",
    "Submit": "Hyv\u00e4ksy",
    "Success": "Onnistui",
    "Successfully added label(s) for library {placeholder}": "Onnistuneesti lis\u00e4tty etiketti(t) kirjastolle {placeholder}",
    "Successfully change the group": "Successfully change the group",
    "Successfully changed library password.": "Kirjaston salasana vaihdettu onnistuneesti.",
    "Successfully cleared trash.": "Successfully cleared trash.",
    "Successfully converted the file.": "Successfully converted the file.",
    "Successfully copied %(name)s and %(amount)s other items.": "Kopioitiin onnistuneesti %(name)s ja %(amount)s muuta kohdetta.",
    "Successfully copied %(name)s and 1 other item.": "Kopioitiin onnistuneesti %(name)s ja 1 muu kohde.",
    "Successfully copied %(name)s.": "%(name)s kopioitiin onnistuneesti.",
    "Successfully copied files to another library.": "Successfully copied files to another library.",
    "Successfully deleted 1 item": "Onnistuneesti tuhottu 1 kohde",
    "Successfully deleted 1 item.": "Onnistuneesti tuhottu 1 kohde.",
    "Successfully deleted 1 share link": "Successfully deleted 1 share link",
    "Successfully deleted 1 user.": "Successfully deleted 1 user.",
    "Successfully deleted {name}": "Successfully deleted {name}",
    "Successfully deleted {name} and {n} other items": "Successfully deleted {name} and {n} other items",
    "Successfully deleted {name} and {n} other items.": "Successfully deleted {name} and {n} other items.",
    "Successfully deleted {name}.": "Successfully deleted {name}.",
    "Successfully deleted {number_placeholder} share links": "Successfully deleted {number_placeholder} share links",
    "Successfully deleted {user_number_placeholder} users.": "Successfully deleted {user_number_placeholder} users.",
    "Successfully edited labels.": "Onnistuneesti muokattu etikettej\u00e4.",
    "Successfully invited %(email) and %(num) other people.": "Onnistuneesti kutsuttu %(email) ja %(num) muuta k\u00e4ytt\u00e4j\u00e4\u00e4.",
    "Successfully invited %(email).": "Onnistuneesti kutsuttu %(email).",
    "Successfully moved %(name)s and %(amount)s other items.": "Siirrettiin onnistuneesti %(name)s ja %(amount)s muuta kohdetta.",
    "Successfully moved %(name)s and 1 other item.": "Siirrettiin onnistuneesti %(name)s ja 1 muu kohde.",
    "Successfully moved %(name)s.": "%(name)s siirretty onnistuneesti.",
    "Successfully moved files to another library.": "Successfully moved files to another library.",
    "Successfully moved {name}.": "Successfully moved {name}.",
    "Successfully restored the library {library_name}.": "Successfully restored the library {library_name}.",
    "Successfully restored the library.": "Kirjasto palautettu onnistuneesti.",
    "Successfully restored.": "Successfully restored.",
    "Successfully revoke the admin permission of %s": "Yll\u00e4pit\u00e4j\u00e4n oikeudet poistettu onnistuneesti k\u00e4ytt\u00e4j\u00e4lt\u00e4 %s",
    "Successfully revoked access of user {placeholder}.": "Successfully revoked access of user {placeholder}.",
    "Successfully revoked the admin permission of {placeholder}.": "Successfully revoked the admin permission of {placeholder}.",
    "Successfully saved": "Successfully saved",
    "Successfully sent to {placeholder}": "L\u00e4hetetty onnistuneesti kohteeseen {placeholder}",
    "Successfully set %s as admin.": "Onnistuneesti asetettu %s yll\u00e4pit\u00e4j\u00e4ksi",
    "Successfully set it.": "Successfully set it.",
    "Successfully set library history.": "Kirjaston historia asetettu onnistuneesti.",
    "Successfully starred {library_name_placeholder}.": "Successfully starred {library_name_placeholder}.",
    "Successfully transferred the group.": "Ryhm\u00e4 siirrettiin onnistuneesti.",
    "Successfully transferred the library.": "Kirjasto siirretty onnistuneesti.",
    "Successfully unlinked the device.": "Successfully unlinked the device.",
    "Successfully unshared library {placeholder}": "Kirjaston jako {placeholder} poistettiin onnistuneesti",
    "Successfully unshared {name}": "Successfully unshared {name}",
    "Successfully unstarred {library_name_placeholder}.": "Successfully unstarred {library_name_placeholder}.",
    "Suggestion": "Suggestion",
    "Switch sort mode": "Switch sort mode",
    "Switch to plain text editor": "Switch to plain text editor",
    "Switch to rich text editor": "Switch to rich text editor",
    "Switch view mode": "Switch view mode",
    "Sync": "Synkronoi",
    "Sync Download": "Sync Download",
    "Sync Upload": "Sync Upload",
    "System": "J\u00e4rjestelm\u00e4",
    "System Admin": "J\u00e4rjestelm\u00e4n hallinta",
    "System Info": "J\u00e4rjestelm\u00e4n info",
    "System settings updated": "System settings updated",
    "Table": "Taulu",
    "Tag not found": "Tag not found",
    "Tagged Files": "Tagged Files",
    "Tags": "Tagit",
    "Team name": "Team name",
    "Template": "Pohja",
    "Terms": "Ehdot",
    "Terms and Conditions": "K\u00e4ytt\u00f6ehdot",
    "Text": "Teksti",
    "Text is required.": "Text is required.",
    "The content of the document has exceeded the limit of 100000 characters, and only the first 100000 characters are saved": "The content of the document has exceeded the limit of 100000 characters, and only the first 100000 characters are saved",
    "The content of the document has exceeded the limit of 100000 characters, and the content cannot be saved": "The content of the document has exceeded the limit of 100000 characters, and the content cannot be saved",
    "The custom part of the URL must be between 5 and 30 characters long and may only contain letters (a-z), numbers, and hyphens.": "The custom part of the URL must be between 5 and 30 characters long and may only contain letters (a-z), numbers, and hyphens.",
    "The file is too large. Allowed maximum size is 1MB.": "The file is too large. Allowed maximum size is 1MB.",
    "The imported options are invalid": "The imported options are invalid",
    "The least number of characters a share/upload link password should include.": "The least number of characters a share/upload link password should include.",
    "The least number of characters an encrypted library password should include.": "V\u00e4himm\u00e4ism\u00e4\u00e4r\u00e4 merkeille salatun kirjaston salasanassa.",
    "The level(1-4) of a share/upload link password's strength. For example, '3' means password must have at least 3 of the following: num, upper letter, lower letter and other symbols": "The level(1-4) of a share/upload link password's strength. For example, '3' means password must have at least 3 of the following: num, upper letter, lower letter and other symbols",
    "The link is copied to the clipboard.": "The link is copied to the clipboard.",
    "The list of added, deleted and modified files will be sent to your mailbox.": "The list of added, deleted and modified files will be sent to your mailbox.",
    "The maximum number of failed login attempts before showing CAPTCHA.": "Enimm\u00e4ism\u00e4\u00e4r\u00e4 ep\u00e4onnistuneita kirjautumisyrityksi\u00e4 ennen CAPTCHA n\u00e4ytt\u00e4mist\u00e4.",
    "The name \"{name}\" is already taken. Please choose a different name.": "The name \"{name}\" is already taken. Please choose a different name.",
    "The next month": "The next month",
    "The next numbers of days": "The next numbers of days",
    "The next week": "The next week",
    "The next year": "The next year",
    "The owner of this library has run out of space.": "T\u00e4m\u00e4n kirjaston omistaja on ylitt\u00e4nyt levykiinti\u00f6n.",
    "The password is too short.": "The password is too short.",
    "The password is too weak. It should include at least {passwordStrengthLevel} of the following: number, upper letter, lower letter and other symbols.": "The password is too weak. It should include at least {passwordStrengthLevel} of the following: number, upper letter, lower letter and other symbols.",
    "The password will be kept in the server for only 1 hour.": "Salasanaa pidet\u00e4\u00e4n palvelimella vain 1 tunti.",
    "The past month": "The past month",
    "The past numbers of days": "The past numbers of days",
    "The past week": "The past week",
    "The past year": "The past year",
    "There is another option with this name": "There is another option with this name",
    "There is another property with this name": "There is another property with this name",
    "There is no information to display.": "There is no information to display.",
    "This file has (apparently) not been accessed yet": "T\u00e4t\u00e4 tiedostoa ei ole (ilmeisesti) viel\u00e4 avattu",
    "This file has been updated.": "This file has been updated.",
    "This folder has been shared to {user_amount} user(s) and {group_amount} group(s).": "This folder has been shared to {user_amount} user(s) and {group_amount} group(s).",
    "This folder has no content at this time.": "This folder has no content at this time.",
    "This is a special group representing a department.": "T\u00e4m\u00e4 on erityisryhm\u00e4, joka edustaa osastoa.",
    "This is required": "This is required",
    "This library has been set to read-only by admin and cannot be updated.": "This library has been set to read-only by admin and cannot be updated.",
    "This library has been shared to {user_amount} user(s) and {group_amount} group(s).": "This library has been shared to {user_amount} user(s) and {group_amount} group(s).",
    "This library is password protected": "T\u00e4m\u00e4 hakemisto on suojattu salasanalla",
    "This month": "This month",
    "This operation will not be reverted. Please think twice!": "T\u00e4t\u00e4 toimintoa ei voi perua. Ole hyv\u00e4 ja harkitse kahdesti!",
    "This property can not be deleted": "This property can not be deleted",
    "This property does not support sorting": "This property does not support sorting",
    "This property is not editable": "This property is not editable",
    "This user has not created or joined any groups": "T\u00e4m\u00e4 k\u00e4ytt\u00e4j\u00e4 ei ole luonut tai liittynyt mihink\u00e4\u00e4n ryhmiin",
    "This week": "This week",
    "This year": "This year",
    "Thumbnail": "Thumbnail",
    "Time": "Aika",
    "Tip: -2 means no limit.": "Vinkki: -2 tarkoittaa ei rajaa.",
    "Tip: 0 means default limit": "Vinkki: 0 tarkoittaa oletuskiinti\u00f6t\u00e4",
    "Tip: a snapshot will be generated after modification, which records the library state after the modification.": "Vinkki: Kirjaston tilannekuva tallennetaan muokkauksen j\u00e4lkeen.",
    "Tip: libraries deleted {placeholder} days ago will be cleaned automatically.": "Tip: libraries deleted {placeholder} days ago will be cleaned automatically.",
    "Tip: libraries deleted {trashReposExpireDays} days ago will be cleaned automatically.": "Tip: libraries deleted {trashReposExpireDays} days ago will be cleaned automatically.",
    "Tip: you can search by keyword in name or ID.": "Tip: you can search by keyword in name or ID.",
    "Tip: you can search by keyword in name.": "Vinkki: voit etsi\u00e4 hakusanalla nimest\u00e4.",
    "Today": "Today",
    "Token": "Varmenne",
    "Token:": "Token:",
    "Tomorrow": "Tomorrow",
    "Too many requests": "Too many requests",
    "Total Devices": "Laitteita yhteens\u00e4",
    "Total Storage": "Total Storage",
    "Total Users": "K\u00e4ytt\u00e4ji\u00e4 yhteens\u00e4",
    "Traffic": "Liikenne",
    "Transfer": "Siirr\u00e4",
    "Transfer Group": "Siirr\u00e4 Ryhm\u00e4",
    "Transfer Group {placeholder} to": "Transfer Group {placeholder} to",
    "Transfer Library": "Siirr\u00e4 Kirjasto",
    "Transfer Library {library_name}": "Transfer Library {library_name}",
    "Transfer group to": "Transfer group to",
    "Transfer to department": "Transfer to department",
    "Transfer to user": "Transfer to user",
    "Transferred group {group_name} from {user_from} to {user_to}": "Siirr\u00e4 ryhm\u00e4 {group_name} k\u00e4ytt\u00e4j\u00e4lt\u00e4 {user_from} k\u00e4ytt\u00e4j\u00e4lle {user_to}",
    "Transferred library {library_name} from {user_from} to {user_to}": "Siirr\u00e4 kirjasto {library_name} k\u00e4ytt\u00e4j\u00e4lt\u00e4 {user_from} k\u00e4ytt\u00e4j\u00e4lle {user_to}",
    "Trash": "Roskakori",
    "Turn off": "Turn off",
    "Turn off extended properties": "Turn off extended properties",
    "Turn on extensible properties and views to experience a new way of managing files": "Turn on extensible properties and views to experience a new way of managing files",
    "Two-Factor Authentication": "Kaksisuuntainen tunnistautuminen",
    "Two-factor authentication is not enabled for your account. Enable two-factor authentication for enhanced account security.": "Kaksitasoinen todennus ei ole k\u00e4yt\u00f6ss\u00e4 tiliss\u00e4si. Ota kaksitasoinen tunnistus k\u00e4ytt\u00f6\u00f6n suojataksesi paremmin tilisi.",
    "Type": "Tyyppi",
    "Type characters to start search": "Type characters to start search",
    "URL is copied to the clipboard": "URL is copied to the clipboard",
    "URL is required": "URL is required",
    "US": "US",
    "Undo": "Undo",
    "Unfreeze Document": "Unfreeze Document",
    "Unhandled": "Unhandled",
    "Unknown": "Tuntematon",
    "Unlink": "Poista linkki",
    "Unlink device": "Poista yhdistetty laite",
    "Unlock": "Poista lukitus",
    "Unselect": "Unselect",
    "Unshare": "Poista jako",
    "Unshare Library": "Poista kirjaton jako",
    "Unstar": "Poista merkint\u00e4",
    "Untitled": "Untitled",
    "Unwatch File Changes": "Unwatch File Changes",
    "Up": "Up",
    "Update": "P\u00e4ivit\u00e4",
    "Update Terms and Conditions": "P\u00e4ivit\u00e4 K\u00e4ytt\u00f6ehdot",
    "Update password": "Update password",
    "Update succeeded.": "Update succeeded.",
    "Updated draft": "Updated draft",
    "Updated file": "Updated file",
    "Upgrade to Pro Edition": "P\u00e4ivit\u00e4 Pro versioon",
    "Upload": "Lis\u00e4\u00e4",
    "Upload Files": "Lis\u00e4\u00e4 tiedostoja",
    "Upload Folder": "Lis\u00e4\u00e4 kansio",
    "Upload Link": "L\u00e4hetyslinkki",
    "Upload Links": "L\u00e4hetyslinkit",
    "Upload file": "Lis\u00e4\u00e4 tiedosto",
    "Upload license": "Upload license",
    "Upload link is copied to the clipboard.": "Upload link is copied to the clipboard.",
    "Uploading...": "Uploading...",
    "Use custom CSS": "K\u00e4yt\u00e4 muokattua CSS",
    "Use information from your Identity Provider to configure Seafile": "Use information from your Identity Provider to configure Seafile",
    "Use the import/export function to transfer options quickly. (The export is in JSON format.) By pasting cells, copied from a text column, an Excel or a TXT file, you can also add options quickly.": "Use the import/export function to transfer options quickly. (The export is in JSON format.) By pasting cells, copied from a text column, an Excel or a TXT file, you can also add options quickly.",
    "Use these values to configure your Identity Provider": "Use these values to configure your Identity Provider",
    "Used:": "K\u00e4ytetty:",
    "User": "K\u00e4ytt\u00e4j\u00e4",
    "User Permission": "K\u00e4ytt\u00e4j\u00e4n oikeudet",
    "User Shares": "User Shares",
    "User Storage": "User Storage",
    "User can not see this folder.": "User can not see this folder.",
    "User can only view files online via browser. Files can't be downloaded.": "User can only view files online via browser. Files can't be downloaded.",
    "User can read, download and sync files.": "User can read, download and sync files.",
    "User can read, write, upload, download and sync files.": "User can read, write, upload, download and sync files.",
    "User can view and edit file online via browser. Files can't be downloaded.": "User can view and edit file online via browser. Files can't be downloaded.",
    "User info updated": "User info updated",
    "User migrate from {user_from} to {user_to}": "User migrate from {user_from} to {user_to}",
    "User not found": "User not found",
    "User {user_link} has added you to {group_link}": "User {user_link} has added you to {group_link}",
    "Username:": "K\u00e4ytt\u00e4j\u00e4nimi:",
    "Users": "K\u00e4ytt\u00e4j\u00e4t",
    "Verified": "Verified",
    "Verify": "Vahvista",
    "Verify Domain": "Verify Domain",
    "Version": "Versiot",
    "Version Number": "Versionumero",
    "Version Number is required.": "Version Number is required.",
    "Version Number must be a number.": "Version Number must be a number.",
    "Video": "Video",
    "View": "Katso",
    "View Link": "View Link",
    "View Related Snapshot": "View Related Snapshot",
    "View Snapshot": "Katso tilannekuva",
    "View profile and more": "Katse profiilia ja muita tietoja",
    "Views": "Views",
    "Virus": "Virus",
    "Virus File": "Virustiedosto",
    "Virus Scan": "Virusskannaus",
    "Visit count": "Visit count",
    "Visit old version page": "Visit old version page",
    "Visited": "Vierailtu",
    "Visits": "Vierailut",
    "Watch File Changes": "Watch File Changes",
    "Web API Auth Token": "Web API Auth Token",
    "Web Download": "Web Download",
    "Web Traffic": "Web Liikenne",
    "Web Upload": "Web Upload",
    "WebDAV Access": "WebDAV Access",
    "WebDAV password:": "WebDAV password:",
    "WebDAV username:": "WebDAV username:",
    "Wiki custom URL deleted": "Wiki custom URL deleted",
    "Wiki owner": "Wiki owner",
    "Wiki published": "Wiki published",
    "Wikis": "Wikit",
    "Wrong password": "V\u00e4\u00e4r\u00e4 salasana",
    "Year": "Year",
    "Yesterday": "Yesterday",
    "You can also add a user as a guest, who will not be allowed to create libraries and groups.": "Voit my\u00f6s lis\u00e4t\u00e4 k\u00e4ytt\u00e4j\u00e4n vieraaksi jotka eiv\u00e4t voi luoda kirjastoja ja ryhmi\u00e4.",
    "You can create files quickly": "You can create files quickly",
    "You can enter multiple emails. An invitation link will be sent to each of them.": "You can enter multiple emails. An invitation link will be sent to each of them.",
    "You can use this field at login.": "Voit k\u00e4ytt\u00e4\u00e4 t\u00e4t\u00e4 kentt\u00e4\u00e4 kirjautumisessa.",
    "You do not have permission": "You do not have permission",
    "You don't have any favorite items yet": "You don't have any favorite items yet",
    "You don't have any share links": "You don't have any share links",
    "You don't have any upload links": "Sinulla ei ole yht\u00e4\u00e4n l\u00e4hetyslinkki\u00e4",
    "You have not accessed your files with any client (desktop or mobile) yet. Configure clients on your devices to access your data more comfortably.": "You have not accessed your files with any client (desktop or mobile) yet. Configure clients on your devices to access your data more comfortably.",
    "You have not added any libraries, folders or files to your favorites yet. A favorite gives you quick access to your most frequently used objects. You can add a library, folder or file to your favorites by clicking the star to the left of its name.": "You have not added any libraries, folders or files to your favorites yet. A favorite gives you quick access to your most frequently used objects. You can add a library, folder or file to your favorites by clicking the star to the left of its name.",
    "You have not created any share links yet. A share link can be used to share files and folders with anyone. You can create a share link for a file or folder by clicking the share icon to the right of its name.": "You have not created any share links yet. A share link can be used to share files and folders with anyone. You can create a share link for a file or folder by clicking the share icon to the right of its name.",
    "You have not created any upload links yet. An upload link allows anyone to upload files to a folder or library. You can create an upload link for a folder or library by clicking the share icon to the right of its name.": "You have not created any upload links yet. An upload link allows anyone to upload files to a folder or library. You can create an upload link for a folder or library by clicking the share icon to the right of its name.",
    "You have not deleted any libraries in the last {placeholder} days. A deleted library will be cleaned automatically after this period.": "You have not deleted any libraries in the last {placeholder} days. A deleted library will be cleaned automatically after this period.",
    "You have not shared any folders": "Et ole jakanut yht\u00e4\u00e4n hakemistoa",
    "You have not shared any folders with other users yet. You can share a folder with other users by clicking the share icon to the right of a folder's name.": "You have not shared any folders with other users yet. You can share a folder with other users by clicking the share icon to the right of a folder's name.",
    "You have not shared any libraries with other users yet. You can share a library with other users by clicking the share icon to the right of a library's name in \"My Libraries\".": "You have not shared any libraries with other users yet. You can share a library with other users by clicking the share icon to the right of a library's name in \"My Libraries\".",
    "Your notifications will be sent to this email.": "Sinun ilmoitukset l\u00e4hetet\u00e4\u00e4n t\u00e4h\u00e4n s\u00e4hk\u00f6postiin.",
    "ZIP": "ZIP",
    "all": "kaikki",
    "all members": "kaikki k\u00e4ytt\u00e4j\u00e4t",
    "contains": "contains",
    "days": "p\u00e4iv\u00e4\u00e4",
    "deleted": "deleted",
    "deleted option": "deleted option",
    "details": "details",
    "does not contain": "does not contain",
    "email is required": "email is required",
    "freezed": "freezed",
    "has all of...": "has all of...",
    "has any of...": "has any of...",
    "has none of...": "has none of...",
    "icon": "ikoni",
    "in all libraries": "in all libraries",
    "include the current user": "include the current user",
    "is": "is",
    "is after...": "is after...",
    "is any of...": "is any of...",
    "is before...": "is before...",
    "is current user's ID": "is current user's ID",
    "is empty": "is empty",
    "is exactly...": "is exactly...",
    "is none of...": "is none of...",
    "is not": "is not",
    "is not empty": "is not empty",
    "is on or after...": "is on or after...",
    "is on or before...": "is on or before...",
    "is within...": "is within...",
    "items": "items",
    "licensed to {placeholder_license_to}, expires on {placeholder_license_expiration}": "licensed to {placeholder_license_to}, expires on {placeholder_license_expiration}",
    "licensed to {placeholder_license_to}, upgrade service expired in {placeholder_license_expiration}": "licensed to {placeholder_license_to}, upgrade service expired in {placeholder_license_expiration}",
    "locked": "lukittu",
    "locked by {name}": "locked by {name}",
    "mm": "mm",
    "name": "nimi",
    "not set": "not set",
    "only show {placeholder}": "only show {placeholder}",
    "s": "s",
    "selected": "selected",
    "show more": "show more",
    "sorts": "sorts",
    "starred": "suosikki",
    "successfully added user %s.": "successfully added user %s.",
    "successfully sent email to %s.": "successfully sent email to %s.",
    "unstarred": "ei suosikki",
    "xxx cells copied": "xxx cells copied",
    "xxx cells selected": "xxx cells selected",
    "xxx record": "xxx record",
    "xxx records": "xxx records",
    "xxx records selected": "xxx records selected",
    "xxx rows are copied.": "xxx rows are copied.",
    "you can also press \u2192": "you can also press \u2192",
    "{failed_files_num} file(s) failed to upload": "{failed_files_num} file(s) failed to upload",
    "{file} and {n} other files": "{file} and {n} other files",
    "{minDays_placeholder} - {maxDays_placeholder} days": "{minDays_placeholder} - {maxDays_placeholder} days",
    "{number_placeholder} / Page": "{number_placeholder} / Page",
    "{placeholder} Access Log": "{placeholder} Access Log",
    "{placeholder} Folder Permission": "{placeholder} Kansion oikeus",
    "{placeholder} History Setting": "{placeholder} Historia-asetukset",
    "{placeholder} Modification History": "{placeholder} Modification History",
    "{placeholder} Share Admin": "{placeholder} Share Admin",
    "{placeholder} Snapshot": "{placeholder} Snapshot",
    "{placeholder} Trash": "{placeholder} Trash",
    "{placeholder} Wiki Trash": "{placeholder} Wiki Trash",
    "{share_from} has cancelled the sharing of folder {repo_name}.": "{share_from} has cancelled the sharing of folder {repo_name}.",
    "{share_from} has cancelled the sharing of library {repo_name}.": "{share_from} has cancelled the sharing of library {repo_name}.",
    "{share_from} has changed the permission of folder {repo_link} to {permission}.": "{share_from} has changed the permission of folder {repo_link} to {permission}.",
    "{share_from} has changed the permission of library {repo_link} to {permission}.": "{share_from} has changed the permission of library {repo_link} to {permission}.",
    "{share_from} has shared a folder named {repo_link} to group {group_link}.": "{share_from} has shared a folder named {repo_link} to group {group_link}.",
    "{share_from} has shared a folder named {repo_link} to you.": "{share_from} has shared a folder named {repo_link} to you.",
    "{share_from} has shared a library named {repo_link} to group {group_link}.": "{share_from} has shared a library named {repo_link} to group {group_link}.",
    "{share_from} has shared a library named {repo_link} to you.": "{share_from} has shared a library named {repo_link} to you.",
    "{uploaded_files_num}/{all_files_num} Files": "{uploaded_files_num}/{all_files_num} Files",
    "{userCount} user(s) and {repoCount} libraries of this organization will also be deleted.": "{userCount} user(s) and {repoCount} libraries of this organization will also be deleted.",
    "{user} created file {fileName} and {fileCount} other file(s) in library {libraryName}.": "{user} created file {fileName} and {fileCount} other file(s) in library {libraryName}.",
    "{user} created file {fileName} in library {libraryName}.": "{user} created file {fileName} in library {libraryName}.",
    "{user} created folder {folderName} and {folderCount} other folder(s) in library {libraryName}.": "{user} created folder {folderName} and {folderCount} other folder(s) in library {libraryName}.",
    "{user} created folder {folderName} in library {libraryName}.": "{user} created folder {folderName} in library {libraryName}.",
    "{user} deleted file {fileName} and {fileCount} other file(s) in library {libraryName}.": "{user} deleted file {fileName} and {fileCount} other file(s) in library {libraryName}.",
    "{user} deleted file {fileName} in library {libraryName}.": "{user} deleted file {fileName} in library {libraryName}.",
    "{user} deleted folder {folderName} and {folderCount} other folder(s) in library {libraryName}.": "{user} deleted folder {folderName} and {folderCount} other folder(s) in library {libraryName}.",
    "{user} deleted folder {folderName} in library {libraryName}.": "{user} deleted folder {folderName} in library {libraryName}.",
    "{user} moved file {fileName} and {fileCount} other file(s) in library {libraryName}.": "{user} moved file {fileName} and {fileCount} other file(s) in library {libraryName}.",
    "{user} moved file {fileName} in library {libraryName}.": "{user} moved file {fileName} in library {libraryName}.",
    "{user} moved folder {folderName} and {folderCount} other folder(s) in library {libraryName}.": "{user} moved folder {folderName} and {folderCount} other folder(s) in library {libraryName}.",
    "{user} moved folder {folderName} in library {libraryName}.": "{user} moved folder {folderName} in library {libraryName}.",
    "{user} renamed file {oldFileName} {fileName} in library {libraryName}.": "{user} renamed file {oldFileName} {fileName} in library {libraryName}.",
    "{user} renamed folder {oldFolderName} {folderName} in library {libraryName}.": "{user} renamed folder {oldFolderName} {folderName} in library {libraryName}.",
    "{user} restored file {fileName} in library {libraryName}.": "{user} restored file {fileName} in library {libraryName}.",
    "{user} restored folder {folderName} in library {libraryName}.": "{user} restored folder {folderName} in library {libraryName}.",
    "{user} updated file {fileName} in library {libraryName}.": "{user} updated file {fileName} in library {libraryName}."
  };
  for (const key in newcatalog) {
    django.catalog[key] = newcatalog[key];
  }
  

  if (!django.jsi18n_initialized) {
    django.gettext = function(msgid) {
      const value = django.catalog[msgid];
      if (typeof value === 'undefined') {
        return msgid;
      } else {
        return (typeof value === 'string') ? value : value[0];
      }
    };

    django.ngettext = function(singular, plural, count) {
      const value = django.catalog[singular];
      if (typeof value === 'undefined') {
        return (count == 1) ? singular : plural;
      } else {
        return value.constructor === Array ? value[django.pluralidx(count)] : value;
      }
    };

    django.gettext_noop = function(msgid) { return msgid; };

    django.pgettext = function(context, msgid) {
      let value = django.gettext(context + '\x04' + msgid);
      if (value.includes('\x04')) {
        value = msgid;
      }
      return value;
    };

    django.npgettext = function(context, singular, plural, count) {
      let value = django.ngettext(context + '\x04' + singular, context + '\x04' + plural, count);
      if (value.includes('\x04')) {
        value = django.ngettext(singular, plural, count);
      }
      return value;
    };

    django.interpolate = function(fmt, obj, named) {
      if (named) {
        return fmt.replace(/%\(\w+\)s/g, function(match){return String(obj[match.slice(2,-2)])});
      } else {
        return fmt.replace(/%s/g, function(match){return String(obj.shift())});
      }
    };


    /* formatting library */

    django.formats = {
    "DATETIME_FORMAT": "j. E Y \\k\\e\\l\\l\\o G.i",
    "DATETIME_INPUT_FORMATS": [
      "%d.%m.%Y %H.%M.%S",
      "%d.%m.%Y %H.%M.%S.%f",
      "%d.%m.%Y %H.%M",
      "%d.%m.%y %H.%M.%S",
      "%d.%m.%y %H.%M.%S.%f",
      "%d.%m.%y %H.%M",
      "%Y-%m-%d %H:%M:%S",
      "%Y-%m-%d %H:%M:%S.%f",
      "%Y-%m-%d %H:%M",
      "%Y-%m-%d"
    ],
    "DATE_FORMAT": "j. E Y",
    "DATE_INPUT_FORMATS": [
      "%d.%m.%Y",
      "%d.%m.%y",
      "%Y-%m-%d"
    ],
    "DECIMAL_SEPARATOR": ",",
    "FIRST_DAY_OF_WEEK": 1,
    "MONTH_DAY_FORMAT": "j. F",
    "NUMBER_GROUPING": 3,
    "SHORT_DATETIME_FORMAT": "j.n.Y G.i",
    "SHORT_DATE_FORMAT": "j.n.Y",
    "THOUSAND_SEPARATOR": "\u00a0",
    "TIME_FORMAT": "G.i",
    "TIME_INPUT_FORMATS": [
      "%H.%M.%S",
      "%H.%M.%S.%f",
      "%H.%M",
      "%H:%M:%S",
      "%H:%M:%S.%f",
      "%H:%M"
    ],
    "YEAR_MONTH_FORMAT": "F Y"
  };

    django.get_format = function(format_type) {
      const value = django.formats[format_type];
      if (typeof value === 'undefined') {
        return format_type;
      } else {
        return value;
      }
    };

    /* add to global namespace */
    globals.pluralidx = django.pluralidx;
    globals.gettext = django.gettext;
    globals.ngettext = django.ngettext;
    globals.gettext_noop = django.gettext_noop;
    globals.pgettext = django.pgettext;
    globals.npgettext = django.npgettext;
    globals.interpolate = django.interpolate;
    globals.get_format = django.get_format;

    django.jsi18n_initialized = true;
  }
};

